@@ -47,6 +47,8 @@ class CybosPlusComObjectInner:
                 self._dispatches[name] = dispatch
         return dispatch
 
+is_in_development = False
+
 class CybosPlusComObject:
 
     """
@@ -96,7 +98,8 @@ class CybosPlusComObject:
         except pywinauto.timings.TimeoutError:
             pass
         else:
-            ask_stop.print_control_identifiers()
+            if is_in_development:
+                ask_stop.print_control_identifiers()
             if ask_stop['Static2'].window_text().endswith('종료하시겠습니까?'):
                 ask_stop['Button1'].click()
                 try:
@@ -105,26 +108,28 @@ class CybosPlusComObject:
                 except pywinauto.timings.TimeoutError:
                     pass
                 else:
-                    ask_stop.print_control_identifiers()
+                    if is_in_development:
+                        ask_stop.print_control_identifiers()
                     if ask_stop['Static2'].window_text().endswith('종료할 수 없습니다.'):
                         ask_stop['Button'].click()
-                        raise RuntimeError
+                        raise RuntimeError('cannot stop existing server')
 
         starter = desktop.window(title='CYBOS Starter')
         starter.wait('ready', timeout=10)
-        starter.print_control_identifiers()
+        if is_in_development:
+            starter.print_control_identifiers()
 
         if userid:
             starter['Edit1'].set_text(userid)
         if password:
             starter['Edit2'].set_text(password)
         else:
-            raise RuntimeError
+            raise RuntimeError('no password given')
         if not price_check_only:
             if cert:
                 starter['Edit3'].set_text(cert)
             else:
-                raise RuntimeError
+                raise RuntimeError('no cert password given')
 
         if auto_account_password:
             starter['Button4'].check()
@@ -134,7 +139,8 @@ class CybosPlusComObject:
             except pywinauto.timings.TimeoutError:
                 pass
             else:
-                confirm.print_control_identifiers()
+                if is_in_development:
+                    confirm.print_control_identifiers()
                 confirm['Button'].click()
         if auto_cert_password:
             starter['Button5'].check()
@@ -144,7 +150,8 @@ class CybosPlusComObject:
             except pywinauto.timings.TimeoutError:
                 pass
             else:
-                confirm.print_control_identifiers()
+                if is_in_development:
+                    confirm.print_control_identifiers()
                 confirm['Button'].click()
         if price_check_only:
             starter['Button6'].check()
@@ -159,12 +166,13 @@ class CybosPlusComObject:
             except pywinauto.timings.TimeoutError:
                 should_stop = True
             else:
-                account_password.print_control_identifiers()
+                if is_in_development:
+                    account_password.print_control_identifiers()
                 account_no = account_password['Static'].window_text().split(':')[-1].strip()
                 if account_no in account_passwords:
                     account_password['Edit'].set_text(account_passwords[account_no])
                 else:
-                    raise RuntimeError
+                    raise RuntimeError('no account password given for account %s' % account_no)
                 account_password['Button1'].click()
 
         try:
@@ -190,13 +198,46 @@ class CybosPlusComObject:
         """
         return self.CpUtil.CpCodeMgr.GetStockListByMarket(market)
 
-    def GetKospiCodeList(self, include_preferred_stocks=False, include_reits=True):
-        return self.GetCodeListByMarketAsList(1)
+    def GetKospiCodeList(self):
+        codes = self.GetCodeListByMarketAsList(1)
+        codes = sorted(codes)
+        return codes
 
     def GetKosdaqCodeList(self):
-        return self.GetCodeListByMarketAsList(2)
+        codes = self.GetCodeListByMarketAsList(2)
+        codes = sorted(codes)
+        return codes
 
-    def GetStockDataAsDataFrame(self, code, type, interval, start_date=None, end_date=None):
+    def GetCommonCodeList(self,
+            include_preferred_stock=True,
+            include_etn=False,
+            include_etf=False,
+            include_mutual_fund=False,
+            include_reits=False,
+            include_kosdaq=False):
+
+        codes = self.GetKospiCodeList()
+        codemgr = self.CpUtil.CpCodeMgr
+
+        if not include_preferred_stock:
+            codes = [code for code in codes if code.endswith('0')]
+        if not include_etn:
+            codes = [code for code in codes if not code.startswith('Q')]
+        if not include_etf:
+            codes = [code for code in codes if codemgr.GetStockSectionKind(code) not in [10, 12]]
+        if not include_mutual_fund:
+            codes = [code for code in codes if codemgr.GetStockSectionKind(code) not in [2]]
+        if not include_reits:
+            codes = [code for code in codes if codemgr.GetStockSectionKind(code) not in [3]]
+
+        if include_kosdaq:
+            codes += self.GetKosdaqCodeList()
+
+        codes = sorted(codes)
+
+        return codes
+
+    def GetStockDataAsDataFrame(self, code, chart_type, interval, start_date=None, end_date=None):
         """
         http://cybosplus.github.io/cpsysdib_rtf_1_/stockchart.htm
         """
@@ -253,7 +294,7 @@ class CybosPlusComObject:
             chart.SetInputValue(2, int(internal_start_date.strftime(date_format_input)))
             chart.SetInputValue(4, request_count)
             chart.SetInputvalue(5, fids)
-            chart.SetInputValue(6, ord(type))
+            chart.SetInputValue(6, ord(chart_type))
             chart.SetInputValue(7, int(interval))
             chart.SetInputValue(9, ord('1')) # TODO: 수정주가로 받으면서 append 하는 경우 과거 데이터에 대한 추가보정이 별도로 필요함
 
@@ -278,8 +319,8 @@ class CybosPlusComObject:
 
             df = pd.DataFrame.from_records(records, columns=names)
 
-            from_date = datetime.datetime.strptime(str(df.iloc[0]['날짜']), date_format_input)
-            last_date = datetime.datetime.strptime(str(df.iloc[-1]['날짜']), date_format_input)
+            from_date = datetime.datetime.strptime(df.iloc[0]['날짜'].astype(int).astype(str), date_format_input)
+            last_date = datetime.datetime.strptime(df.iloc[-1]['날짜'].astype(int).astype(str), date_format_input)
             logging.debug('Received data from %s to %s for code %s', from_date, last_date, code)
 
             if end_date is None:
@@ -291,7 +332,7 @@ class CybosPlusComObject:
                 logging.debug('More data to request remains')
                 internal_start_date = last_date
                 nrows_before_truncate = df.shape[0]
-                condition = pd.to_datetime(df['날짜'].astype(str), format='%Y%m%d') > last_date
+                condition = pd.to_datetime(df['날짜'].astype(int).astype(str), format='%Y%m%d') > last_date
                 df = df.loc[condition]
                 nrows_after_truncate = df.shape[0]
                 logging.debug('Trailing rows truncated: %d', nrows_before_truncate - nrows_after_truncate)
@@ -299,7 +340,7 @@ class CybosPlusComObject:
                 logging.debug('No more data to request')
                 if end_date is not None:
                     nrows_before_truncate = df.shape[0]
-                    datetimes = pd.to_datetime(df['날짜'].astype(str).str.cat(df['시간'].astype(str).str.zfill(6)), format='%Y%m%d%H%M%S')
+                    datetimes = pd.to_datetime(df['날짜'].astype(int).astype(str).str.cat(df['시간'].astype(int).astype(str).str.zfill(6)), format='%Y%m%d%H%M%S')
                     condition = datetimes > end_date
                     df = df.loc[condition]
                     nrows_after_truncate = df.shape[0]
