@@ -6,8 +6,7 @@ from PyQt5.QtCore import QEvent, Qt
 
 from koapy.pyqt5.KiwoomOpenApiDynamicCallable import KiwoomOpenApiDynamicCallable
 from koapy.pyqt5.KiwoomOpenApiSignalConnector import KiwoomOpenApiSignalConnector
-from koapy.utils.rate_limiting.RateLimiter import SimpleRateLimiter
-from koapy.openapi.KiwoomOpenApiError import KiwoomOpenApiError
+from koapy.pyqt5.KiwoomOpenApiControlWrapper import KiwoomOpenApiControlWrapper
 from koapy.grpc.event.KiwoomOpenApiEventHandler import KiwoomOpenApiLoggingEventHandler
 from koapy.grpc.event.KiwoomOpenApiEventHandlerFunctions import KiwoomOpenApiEventHandlerFunctions
 
@@ -48,6 +47,7 @@ class KiwoomOpenApiQAxWidget(QWidget):
         super().__init__(*super_args, **super_kwargs)
 
         self._ax = QAxWidget(clsid_or_progid, self)
+        self._ax_wrapped = KiwoomOpenApiControlWrapper(self)
         self._signals = {}
         self._event_logger = KiwoomOpenApiLoggingEventHandler(self)
 
@@ -69,17 +69,19 @@ class KiwoomOpenApiQAxWidget(QWidget):
         self._ax.exception.connect(self._onException)
 
     def _onException(self, code, source, desc, help):
-        logging.error('(%s, %s, %s, %s)', code, source, desc, help)
+        logging.exception('QAxBaseException(%r, %r, %r, %r)', code, source, desc, help)
 
     def __getattr__(self, name):
-        result = getattr(self._ax, name)
-
-        if type(result).__name__ == 'pyqtMethodProxy':
-            return KiwoomOpenApiDynamicCallable(self._ax, name)
-        elif name.startswith('On') and name in self._signals:
-            return self._signals[name]
+        try:
+            result = getattr(self._ax, name)
+        except AttributeError:
+            result = self._ax_wrapped.__getattribute__(name)
         else:
-            return result
+            if type(result).__name__ == 'pyqtMethodProxy':
+                result = KiwoomOpenApiDynamicCallable(self._ax, name)
+            elif name.startswith('On') and name in self._signals:
+                result = self._signals[name]
+        return result
 
     def changeEvent(self, event):
         if event.type() == QEvent.WindowStateChange:
@@ -89,46 +91,3 @@ class KiwoomOpenApiQAxWidget(QWidget):
     def closeEvent(self, event):
         self.hide()
         event.ignore()
-
-    @SimpleRateLimiter(period=4, calls=1) # 그냥 1초당 5회로하면 장기적으로 결국 막히기 때문에 4초당 1회로 제한 (3초당 1회부턴 제한걸림)
-    def RateLimitedCommRqData(self, rqname, trcode, prevnext, scrnno, inputs=None):
-        """
-        [OpenAPI 게시판]
-          https://bbn.kiwoom.com/bbn.openAPIQnaBbsList.do
-
-        [조회횟수 제한 관련 가이드]
-          - 1초당 5회 조회를 1번 발생시킨 경우 : 17초대기
-          - 1초당 5회 조회를 5연속 발생시킨 경우 : 90초대기
-          - 1초당 5회 조회를 10연속 발생시킨 경우 : 3분(180초)대기
-        """
-        prevnext = int(prevnext) # ensure prevnext is int
-        code = self.CommRqData(rqname, trcode, prevnext, scrnno)
-        spec = 'CommRqData(%r, %r, %r, %r)' % (rqname, trcode, prevnext, scrnno)
-
-        if inputs is not None:
-            spec += ' with inputs %r' % inputs
-
-        if code == KiwoomOpenApiError.OP_ERR_NONE:
-            message = 'CommRqData() was successful; ' + spec
-            logging.debug(message)
-        elif code == KiwoomOpenApiError.OP_ERR_SISE_OVERFLOW:
-            message = 'CommRqData() was rejected due to massive request; ' + spec
-            logging.error(message)
-            raise KiwoomOpenApiError(code)
-        elif code == KiwoomOpenApiError.OP_ERR_ORD_WRONG_INPUT:
-            message = 'CommRqData() failed due to wrong input, check if input was correctly set; ' + spec
-            logging.error(message)
-            raise KiwoomOpenApiError(code)
-        elif code in (KiwoomOpenApiError.OP_ERR_RQ_STRUCT_FAIL, KiwoomOpenApiError.OP_ERR_RQ_STRING_FAIL):
-            message = 'CommRqData() request was invalid; ' + spec
-            logging.error(message)
-            raise KiwoomOpenApiError(code)
-        else:
-            message = 'Unknown error occured during CommRqData() request; ' + spec
-            korean_message = KiwoomOpenApiError.get_error_message_by_code(code)
-            if korean_message is not None:
-                message += '; Korean error message: ' +  korean_message
-            logging.error(message)
-            raise KiwoomOpenApiError(code)
-
-        return code
